============
Installation
============

At the command line::

    $ pip install skinfer

If you don't have ``pip``, you can still install it with::

    $ easy_install skinfer

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv skinfer
    $ pip install skinfer
